[][src]Trait samp::cell::repr::AmxCell

pub trait AmxCell<'amx> {
    fn as_cell(&self) -> i32;

    fn from_raw(_amx: &'amx Amx, _cell: i32) -> Result<Self, AmxError>
    where
        Self: 'amx
, { ... } }

AmxCell trait is a core trait of whole SDK. It shows that value can be borrowed (or copied if it's a primitive) from AMX and passed to it.

Required methods

fn as_cell(&self) -> i32

Get a value which can be passed to AMX.

Loading content...

Provided methods

fn from_raw(_amx: &'amx Amx, _cell: i32) -> Result<Self, AmxError> where
    Self: 'amx, 

Loading content...

Implementations on Foreign Types

impl<'_> AmxCell<'_> for bool[src]

impl<'_> AmxCell<'_> for u32[src]

impl<'_> AmxCell<'_> for usize[src]

impl<'a, T> AmxCell<'a> for &'a T where
    T: AmxCell<'a>, 
[src]

fn from_raw(_amx: &'amx Amx, _cell: i32) -> Result<Self, AmxError> where
    Self: 'amx, 
[src]

impl<'_> AmxCell<'_> for i32[src]

impl<'_> AmxCell<'_> for isize[src]

impl<'_> AmxCell<'_> for u16[src]

impl<'_> AmxCell<'_> for u8[src]

impl<'_> AmxCell<'_> for f32[src]

impl<'_> AmxCell<'_> for i16[src]

impl<'a, T> AmxCell<'a> for &'a mut T where
    T: AmxCell<'a>, 
[src]

fn from_raw(_amx: &'amx Amx, _cell: i32) -> Result<Self, AmxError> where
    Self: 'amx, 
[src]

impl<'_> AmxCell<'_> for i8[src]

Loading content...

Implementors

impl<'amx> AmxCell<'amx> for AmxString<'amx>[src]

impl<'amx> AmxCell<'amx> for Buffer<'amx>[src]

fn from_raw(_amx: &'amx Amx, _cell: i32) -> Result<Self, AmxError> where
    Self: 'amx, 
[src]

impl<'amx> AmxCell<'amx> for UnsizedBuffer<'amx>[src]

impl<'amx, T> AmxCell<'amx> for Ref<'amx, T> where
    T: AmxPrimitive
[src]

Loading content...