[][src]Trait samp::cell::repr::AmxPrimitive

pub unsafe trait AmxPrimitive { }

A marker showing that a value can be stored directly on a stack or a heap of an AMX.

Types: i8, u8, i16, u16, i32, u32, usize, isize, f32, bool

There is no values that's bigger than 4 bytes, because size of an AMX cell is 32 bits.

Implementations on Foreign Types

impl AmxPrimitive for u32[src]

impl AmxPrimitive for isize[src]

impl AmxPrimitive for u8[src]

impl AmxPrimitive for i32[src]

impl AmxPrimitive for i8[src]

impl AmxPrimitive for bool[src]

impl AmxPrimitive for f32[src]

impl AmxPrimitive for u16[src]

impl AmxPrimitive for i16[src]

impl AmxPrimitive for usize[src]

Loading content...

Implementors

Loading content...